/**
 * Validate & extract data from Slip Verify QR (for use with Bank Open API)
 *
 * @param payload - QR Code Payload
 * @returns Bank code and Transaction reference or null if payload invalid
 */
declare function slipVerify(payload: string): {
    sendingBank: string;
    transRef: string;
} | null;

/**
 * Validate & extract data from TrueMoney Slip Verify QR
 *
 * @param payload - QR Code Payload
 * @returns Type, Transaction ID and Date (DDMMYYYY) or null if payload invalid
 */
declare function trueMoneySlipVerify(payload: string): {
    eventType: string | undefined;
    transactionId: string | undefined;
    date: string | undefined;
} | null;

declare const index_slipVerify: typeof slipVerify;
declare const index_trueMoneySlipVerify: typeof trueMoneySlipVerify;
declare namespace index {
  export { index_slipVerify as slipVerify, index_trueMoneySlipVerify as trueMoneySlipVerify };
}

export { index as i, slipVerify as s, trueMoneySlipVerify as t };
